import React, { useState } from 'react';
import { IPFS_DOWNLOAD_TYPES_MAP, IPFSDownloadType } from '../utilities/files';
import { WithClassName } from '../types/components';

export type UseDownloadTypeHookReturn = {
  downloadType: IPFSDownloadType;
  setDownloadType: (downloadType: IPFSDownloadType) => void;
};

type DownloadTypeToggleProps = WithClassName &
  UseDownloadTypeHookReturn & {
    disabled?: boolean;
  };

export const DownloadTypeToggle: React.FC<DownloadTypeToggleProps> = ({
  className,
  downloadType,
  setDownloadType,
  disabled,
}) => {
  return (
    <div className={className}>
      {IPFS_DOWNLOAD_TYPES_MAP.map(({ type, label }) => (
        <div key={type} className="form-control md:max-w-xs">
          <label className="label cursor-pointer">
            <span className="label-text mr-4">Download via {label}</span>
            <input
              type="radio"
              name={`download-type-${type}`}
              className="radio"
              checked={downloadType === type}
              onChange={() => setDownloadType(type)}
              disabled={disabled}
            />
          </label>
        </div>
      ))}
    </div>
  );
};

export const useDownloadType = (): UseDownloadTypeHookReturn => {
  const [downloadType, setDownloadType] = useState<IPFSDownloadType>(
    IPFSDownloadType.Gateway,
  );

  return {
    setDownloadType,
    downloadType,
  };
};
