import React from 'react';
import { WithClassName } from '../../types/components';
import cn from 'classnames';

type SelectProps = WithClassName & {
  options: SelectOption[];
  onChange?: (value: string) => void;
};

type SelectOption = {
  value: string | number;
  label: string | number;
};

export const Select: React.FC<SelectProps> = ({
  id,
  className,
  options,
  onChange,
}) => (
  <select
    id={id}
    className={cn(className, 'select select-bordered w-full max-w-xs')}
    onChange={({ target: { value } }) => {
      if (onChange) {
        onChange(value);
      }
    }}
  >
    {options.map(({ value, label }) => (
      <option key={value} value={value}>
        {label}
      </option>
    ))}
  </select>
);
