import React, { ReactNode, useEffect } from 'react';
import { Portal } from './Portal/Portal';
import { Theme, useTheme } from '../../context/ThemeContext';

type Props = {
  children?: ReactNode;
};

const THEME_MAP: Record<Theme, string> = {
  light: 'winter',
  dark: 'night',
};

export const AppWrapper: React.FC<Props> = ({ children }) => {
  const { theme } = useTheme();

  useEffect(() => {
    document.body.setAttribute('data-theme', THEME_MAP[theme]);
  }, [theme]);

  return (
    <div className="w-full h-full">
      <div className="flex w-full min-h-screen h-full md:items-center p-1.5 md:p-4">
        <Portal>{children}</Portal>
      </div>
    </div>
  );
};
