import React, { ReactNode } from 'react';
import { Container } from '../Container';
import { Module, ROUTES as DEFAULT_ROUTES } from '../../../utilities/routes';
import { PortalTabLink } from './PortalTabLink';
import { useRouter } from 'next/router';

type PortalProps = {
  routes?: Module[];
  children?: ReactNode;
};

export const Portal: React.FC<PortalProps> = ({
  routes = DEFAULT_ROUTES,
  children,
}) => {
  const { pathname } = useRouter();

  return (
    <Container className="w-full mx-auto">
      <div className="card border mb-2">
        <div className="grid grid-flow-row md:grid-flow-col gap-2 m-2">
          {routes.map(({ href, label, pathname: routePathname }) => (
            <PortalTabLink
              key={href}
              href={href}
              active={routePathname === pathname}
            >
              {label}
            </PortalTabLink>
          ))}
        </div>
      </div>
      <div className="card border">{children}</div>
      <p className="text-center p-4 text-gray-500">
        Copyright &copy; {new Date().getFullYear()} Petr Schmidt (University of
        Hradec Králové)
      </p>
    </Container>
  );
};
