import { create, IPFS } from 'ipfs-core';
import { concat as uint8ArrayConcat } from 'uint8arrays/concat';
import all from 'it-all';

export let ipfs: IPFS | undefined = undefined;

declare global {
  interface Window {
    ipfs: any;
  }
}

export const initIPFS = async (): Promise<IPFS> =>
  new Promise(async (resolve, reject) => {
    if (ipfs) {
      resolve(ipfs);
    } else if (window.ipfs && window.ipfs.enable) {
      ipfs = await window.ipfs.enable({ commands: ['id'] });
      resolve(ipfs as IPFS);
    } else {
      try {
        ipfs = await create({ repo: '/axiom-ipfs-repo' });
        resolve(ipfs);
      } catch (error) {
        ipfs = undefined;
        reject();
      }
    }
  });

export const queryIPFS = async (cid: string): Promise<Blob> =>
  new Promise((resolve, reject) => {
    initIPFS()
      .then(async (node) => {
        resolve(new Blob([uint8ArrayConcat(await all(node.cat(cid)))]));
      })
      .catch(reject);
  });
